@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-36be845f4f1d6637b31b996096fb7b64
-key: yesod_B5n4gF9sbIqGw6CiPJKWF8
+id: yesod-1.4.2-8994ae96a816d1aace7e2b388f9ba84e
+key: yesod_82vSA8z2cdILdixikGgx8t
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,9 +21,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-B5n4gF9sbIqGw6CiPJKWF8
+hs-libraries: HSyesod-1.4.2-82vSA8z2cdILdixikGgx8t
 depends:
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
@@ -36,7 +36,7 @@ depends:
     monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-423d40cf84610c6e09dcfa0707b6b283
+    shakespeare-2.0.7-eabbf817e7dec503c762bf3ca866120e
     streaming-commons-0.1.15.1-aa72527d91e580265833d7825d2659ed
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.13.1-dbbab62e08152a1a89e4fd5c9bc43b08
+    wai-extra-3.0.13.1-22d19709bfcccb29f4594bf354c81852
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.1-dece252cc38d42a08927d0fe50612a60
-    yaml-0.8.16-de73bc65fca64164779e57dd8dda918f
-    yesod-auth-1.4.12-697811d5ea6b1ea512e38d809f5294a9
-    yesod-core-1.4.19-f58e956f86f9387c891d6fa112ae88e5
-    yesod-form-1.4.6-0d16987bed7ae5bd9138bcaf56057062
-    yesod-persistent-1.4.0.3-3edc22929bdc95f8a7aaec30b1c13cd6
+    warp-3.2.1-4bdf427d1f92fd4de5e1e827ed9b1276
+    yaml-0.8.16-fb65281075453c8e8a8a864f3d81487b
+    yesod-auth-1.4.12-4eb7c4aac3cb78ba477d936342de8969
+    yesod-core-1.4.19-30aa3dec94572d19698f25c55f6fdd4f
+    yesod-form-1.4.6-3eef7a59d19c1396cc78d85b66648731
+    yesod-persistent-1.4.0.3-ca5a75367b988d48b524d0aecd2cb90c
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
